@@ -1,11 +1,12 @@
 from PyQt4 import QtCore, QtGui
+import utils
 import pydosh_rc
-from models import CheckComboModel
 
 class MultiComboBox(QtGui.QComboBox):
 	""" Extension of QComboBox widget that allows for multiple selection
 	"""
-	selectionChanged = QtCore.pyqtSignal()
+	# Signal containing list of selected indexes
+	selectionChanged = QtCore.pyqtSignal('PyQt_PyObject')
 
 	def __init__(self, parent=None):
 		super(MultiComboBox, self).__init__(parent=parent)
@@ -24,13 +25,25 @@ class MultiComboBox(QtGui.QComboBox):
 
 		self.activated[int].connect(self.__toggleCheckState)
 
+	def reset(self):
+		""" Reset the model and clear selection if necessary
+		"""
+		itemsBefore = [index.data().toString() for index in self.__checkedItems()]
+
+		self.model().select()
+
+		itemsAfter = [index.data().toString() for index in self.__checkedItems()]
+
+		if itemsBefore != itemsAfter:
+			self.clearAll()
+
 	def setModel(self, model):
 		super(MultiComboBox, self).setModel(model)
 		# This is a bit odd, but seem to need it
 		self.setModelColumn(self.modelColumn())
 		model.rowsInserted.connect(self.__updateCheckedItems)
 		model.rowsRemoved.connect(self.__updateCheckedItems)
-		model.checkStateChanged.connect(self.__updateCheckedItems)
+		model.dataChanged.connect(self.__updateCheckedItems)
 		self.__updateCheckedItems()
 
 	def dataChanged(self):
@@ -50,12 +63,9 @@ class MultiComboBox(QtGui.QComboBox):
 		modelIndex = self.model().index(0, self.modelColumn(), self.rootModelIndex())
 		modelIndexList = self.model().match(modelIndex, QtCore.Qt.CheckStateRole, searchState, -1, QtCore.Qt.MatchExactly)
 
-		self.model().blockSignals(True)
-
-		for index in modelIndexList:
-			self.setItemData(index.row(), assignState, QtCore.Qt.CheckStateRole)
-
-		self.model().blockSignals(False)
+		with utils.signalsBlocked(self.model()):
+			for index in modelIndexList:
+				self.setItemData(index.row(), assignState, QtCore.Qt.CheckStateRole)
 
 		self.__updateCheckedItems()
 
@@ -112,18 +122,13 @@ class MultiComboBox(QtGui.QComboBox):
 		value = self.itemData(index, QtCore.Qt.CheckStateRole)
 
 		if value.isValid():
-			state = value.toPyObject()
-			self.setItemData(index, QtCore.Qt.Checked if state == QtCore.Qt.Unchecked else QtCore.Qt.Unchecked, QtCore.Qt.CheckStateRole)
+			if value.toPyObject() == QtCore.Qt.Unchecked:
+				state = QtCore.Qt.Checked
+			else:
+				state = QtCore.Qt.Unchecked
+			self.setItemData(index, state, QtCore.Qt.CheckStateRole)
 
-	def checkedItems(self):
-		items = []
-		if self.model():
-			currentIndex = self.model().index(0, self.modelColumn(), self.rootModelIndex())
-			indexes = self.model().match(currentIndex, QtCore.Qt.CheckStateRole, QtCore.Qt.Checked, -1, QtCore.Qt.MatchExactly)
-			items = [index.data().toString() for index in indexes]
-		return items
-
-	def checkedIndexes(self):
+	def __checkedItems(self):
 		indexes = []
 		if self.model():
 			currentIndex = self.model().index(0, self.modelColumn(), self.rootModelIndex())
@@ -155,14 +160,13 @@ class MultiComboBox(QtGui.QComboBox):
 			signalMap[contextMenuAction]()
 
 	def __updateCheckedItems(self):
-		items = self.checkedItems()
-
+		items = self.__checkedItems()
 		if items:
-			self.setEditText(', '.join([str(item) for item in items]))
+			self.setEditText(QtCore.QStringList([index.data().toString() for index in items]).join(', '))
 		else:
 			self.setEditText(self._defaultText)
 
-		self.selectionChanged.emit()
+		self.selectionChanged.emit(items)
 
 	def showPopup(self):
 		self.__persistDropdown = QtGui.QApplication.keyboardModifiers() == QtCore.Qt.ShiftModifier
@@ -172,8 +176,19 @@ class MultiComboBox(QtGui.QComboBox):
 		if not self.__persistDropdown:
 			super(MultiComboBox, self).hidePopup()
 
-	def __str__(self):
-		return ', '.join([str(item) for item in self.checkedItems()])
+
+class MyCombo(QtGui.QComboBox):
+	def __init__(self, parent=None):
+		super(MyCombo, self).__init__(parent=parent)
+
+	def paintEvent(self, event):
+		painter = QtGui.QStylePainter(self)
+		opt = QtGui.QStyleOptionComboBox()
+		self.initStyleOption(opt)
+		#painter.drawComplexControl(QtGui.QStyle.CC_ComboBox, opt)
+		#painter.drawControl(QtGui.QStyle.CE_ComboBoxLabel, opt)
+#		super(MyCombo, self).paintEvent(event)
+
 
 
 def main():
@@ -184,17 +199,29 @@ def main():
 	#app.setStyle(QtGui.QStyleFactory.create("Plastique"))
 	#pdb.set_trace()
 	#lineEdit = SearchLineEdit()
-	widget = MultiComboBox()
+	combo = MyCombo()
+	import pdb
+	pdb.set_trace()
+	combo.setFrame(False)
+#	combo.setStyleSheet ("QComboBox::drop-down {border-width: 0px;} QComboBox::down-arrow {image: url(noimg); border-width: 0px;}")
 	#tracer.monitor(lineEdit, widget, lineEdit.clearButton)
 
 	#widget.setLineEdit(lineEdit)
 	#lineEdit.clearButtonPressed.connect(widget.clearAll)
-	widget.addItems(['item %d' %i for i in xrange(2)])
+	label = QtGui.QLabel('releaseTime')
+	combo.addItem(QtGui.QIcon('in.png'), '')
+	combo.addItem(QtGui.QIcon('ca.png'), '')
+	combo.addItem(QtGui.QIcon('gb.png'), '')
+	combo.addItem(QtGui.QIcon('us.png'), '')
+	#widget.addItems(['item %d' %i for i in xrange(2)])
 #	widget.setDefaultText('all')
 
 	dialog = QtGui.QDialog()
 	layout = QtGui.QVBoxLayout()
-	layout.addWidget(widget)
+	hLayout = QtGui.QHBoxLayout()
+	hLayout.addWidget(label)
+	hLayout.addWidget(combo)
+	layout.addLayout(hLayout)
 
 	dialog.setLayout(layout)
 	dialog.show()
